/*
 * <%= @warning %>
 *
 * Copyright (C) 2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#import "WebViewInternal.h"

#import "WebPreferencesDefinitions.h"
#import "WebPreferencesInternal.h"
#import "WebViewData.h"
#import <WebCore/DeprecatedGlobalSettings.h>
#import <WebCore/Page.h>
#import <WebCore/RuntimeEnabledFeatures.h>
#import <WebCore/Settings.h>

@implementation WebView (WebViewInternalPreferencesChangedGenerated)

- (void)_preferencesChangedGenerated:(WebPreferences *)preferences
{
    auto& settings = _private->page->settings();

<%- for @pref in @preferencesBoundToSetting.select { |p| !p.opts["webKitLegacyBinding"] } do -%>
<%- if @pref.condition -%>
#if <%= @pref.condition %>
<%- end -%>
<%- if @pref.exposed -%>
    settings.set<%= @pref.webcoreNameUpper %>([preferences <%= @pref.preferenceAccessor %>:@"<%= @pref.preferenceKey %>"]);
<%- else -%>
    settings.set<%= @pref.webcoreNameUpper %>(DEFAULT_VALUE_FOR_<%= @pref.name %>);
<%- end -%>
<%- if @pref.condition -%>
#endif
<%- end -%>
<%- end -%>

<%- for @pref in @preferencesBoundToDeprecatedGlobalSettings.select { |p| !p.opts["webKitLegacyBinding"] } do -%>
<%- if @pref.condition -%>
#if <%= @pref.condition %>
<%- end -%>
<%- if @pref.exposed -%>
    WebCore::DeprecatedGlobalSettings::set<%= @pref.webcoreNameUpper %>([preferences <%= @pref.preferenceAccessor %>:@"<%= @pref.preferenceKey %>"]);
<%- else -%>
    WebCore::DeprecatedGlobalSettings::set<%= @pref.webcoreNameUpper %>(DEFAULT_VALUE_FOR_<%= @pref.name %>);
<%- end -%>
<%- if @pref.condition -%>
#endif
<%- end -%>
<%- end -%>

<%- for @pref in @preferencesBoundToRuntimeEnabledFeatures.select { |p| !p.opts["webKitLegacyBinding"] } do -%>
<%- if @pref.condition -%>
#if <%= @pref.condition %>
<%- end -%>
<%- if @pref.exposed -%>
    WebCore::RuntimeEnabledFeatures::sharedFeatures().set<%= @pref.webcoreNameUpper %>([preferences <%= @pref.preferenceAccessor %>:@"<%= @pref.preferenceKey %>"]);
<%- else -%>
    WebCore::RuntimeEnabledFeatures::sharedFeatures().set<%= @pref.webcoreNameUpper %>(DEFAULT_VALUE_FOR_<%= @pref.name %>);
<%- end -%>
<%- if @pref.condition -%>
#endif
<%- end -%>
<%- end -%>
}

@end
